import { default as React } from 'react';
import { ColumnKey } from './Column';
import { Smartable } from './Smartable';

/**
 * Smartable cell definition.
 */
export interface CellDefinition<T = any> {
    /**
     * Cell data.
     */
    data: T;
    /**
     * Rendered cell element.
     */
    element?: React.ReactElement;
}
/**
 * Default cell component.
 */
export declare function Cell({ children, ...props }: React.PropsWithChildren<React.TdHTMLAttributes<HTMLTableCellElement>>): React.JSX.Element;
/**
 * Table cell context data.
 */
export interface CellContextData<CK extends ColumnKey, T = any> extends CellDefinition<T> {
}
/**
 * Hook to get current cell data.
 */
export declare function useCell<CK extends ColumnKey, T = any>(smartable?: Smartable<CK>): CellContextData<CK, T>;
/**
 * Cell instance component.
 */
export declare function CellInstance<T>({ cell }: {
    cell: CellDefinition<T>;
}): React.JSX.Element;
/**
 * Animated cell loader.
 */
export declare function CellLoader(): React.JSX.Element;
