import { default as React } from 'react';
import { ColumnKey, Columns } from './Column';
import { SmartableProperties } from './Smartable';

/**
 * Smartable instance component properties.
 */
export interface InstanceProperties<CK extends ColumnKey> extends SmartableProperties<CK> {
    /**
     * Table columns.
     */
    columns: Columns<CK>;
}
/**
 * Main component for a Smartable table.
 */
export declare function Instance<CK extends ColumnKey>(props: InstanceProperties<CK>): React.JSX.Element;
/**
 * Paginated Smartable instance component.
 */
export declare function PaginatedInstance<CK extends ColumnKey>(props: InstanceProperties<CK>): React.JSX.Element;
/**
 * Base component for a Smartable table.
 */
export declare function Table<CK extends ColumnKey>({ className, columns, children }: React.PropsWithChildren<InstanceProperties<CK>>): React.JSX.Element;
/**
 * Columns headings of a Smartable table.
 */
export declare function ColumnsHeadings<CK extends ColumnKey>({ columns }: {
    columns: Columns<CK>;
}): React.JSX.Element;
/**
 * Smartable table body.
 */
export declare function TableBody<CK extends ColumnKey>({ pagination }: {
    /**
     * Current pagination state.
     */
    pagination?: {
        page: number;
        pageSize: number;
    };
}): React.JSX.Element | React.JSX.Element[];
