import { default as React } from 'react';
import { ColumnKey } from './Column';
import { CellDefinition } from './Cell';
import { Smartable } from './Smartable';
import { Promisable } from '@kernelui/core';
import { CurrentRowData } from './AsyncManager';

/**
 * Smartable row cells.
 */
export type RowCells<CK extends ColumnKey, T = any> = Record<CK, Promisable<CellDefinition<T>>>;
/**
 * Smartable row data.
 */
export interface RowData<CK extends ColumnKey, T = any> {
    /**
     * Cells definition.
     */
    cells: RowCells<CK, T>;
    /**
     * Rendered row element.
     */
    element?: React.ReactElement;
    /**
     * Rendered row cell element.
     */
    cellElement?: React.ReactElement;
}
/**
 * Smartable row definition.
 */
export type RowDefinition<CK extends ColumnKey> = RowCells<CK> | RowData<CK>;
/**
 * Normalize row definition to row data.
 */
export declare function normalizeRowDefinition<CK extends ColumnKey>(rowDefinition: RowDefinition<CK>): RowData<CK>;
/**
 * Table row context data.
 */
export interface RowContextData<CK extends ColumnKey, T = any> extends CurrentRowData<CK, T> {
}
/**
 * Hook to get current row data.
 */
export declare function useRow<CK extends ColumnKey, T = any>(smartable?: Smartable<CK>): RowContextData<CK, T>;
/**
 * Default row component.
 */
export declare function Row(): React.JSX.Element;
export declare function RowCells(): React.JSX.Element[];
/**
 * Row instance component.
 */
export declare function RowInstance<CK extends ColumnKey>({ row }: {
    row: CurrentRowData<CK>;
}): React.JSX.Element;
/**
 * Animated row loader.
 */
export declare function RowLoader(): React.JSX.Element;
